4.55. umbra.ui.widgets.messageBox — Umbra 1.0.9 documentation

# 4.55. umbra.ui.widgets.messageBox

messageBox.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `messageBox()` and `standaloneMessageBox()` functions.

Others:

## 4.55.1. Module Attributes

`umbra.ui.widgets.messageBox.` `LOGGER`

## 4.55.2. Functions

`umbra.ui.widgets.messageBox.` `messageBox`(type, title, message, icon=None, buttons=1024, customButtons=None)

  Provides a fast GUI message box.

  Parameters: | title (unicode) – Current message title. message (unicode) – Message. icon (QConstant) – Custom icon. buttons (QConstant) – Standard buttons. customButtons (tuple or list) – Custom buttons.
  Returns: | User choice.
  Return type: | int